@@ -22,7 +22,7 @@
 #include "about.h"
 
 void
-about_gtktalog (GtkWidget * w, gpointer data)
+about_gtktalog ()
 {
   GtkWidget *aboutbox;
   const gchar *authors[3] = { "Mathieu VILLEGAS", "Yves METTIER", NULL };
