@@ -21,10 +21,27 @@
 
 #include "config_common.h"
 
-gchar *read_information(CONFIG *my_config, gchar *file);
-void create_folder_tree(CONFIG *my_config, GNode *parent, const gchar *path, gboolean getInformation);
-void *start_thread_scan(void *arg);
-void finish_normal_scan(int sig);
-int start_add_disk(char *foldername, char *diskname, CONFIG *my_config);
+guint du_s (gchar * path);
+gboolean eject_disk(CONFIG *my_config);
+gboolean mount_disk(CONFIG *my_config);
+gboolean umount_disk(CONFIG *my_config);
+
+gint get_thread_status ();
+void reinit_thread_status ();
+void set_thread_status_to_running ();
+void set_thread_status_to_ended ();
+
+void do_not_forget_to_umount (gboolean gb);
+void set_local_disk_name (gchar * s);
+void set_local_folder_name (gchar * s);
+void set_added_disk (gboolean gb);
+
+gint my_timeout (gpointer data);
+
+gchar *read_information (gchar * file);
+void create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
+			 gboolean getInformation);
+void *start_thread_scan (void *arg);
+void finish_normal_scan (int sig);
 
 #endif
