@@ -37,11 +37,36 @@
 #define CAT_TREE_0	0
 #define CAT_TREE_END	99
 
+#define THREAD_SCAN_RUNNING_NO		1
+#define THREAD_SCAN_RUNNING_YES		2
+#define THREAD_SCAN_RUNNING_ENDED	3
+
 #define ERROR_DIALOG(msg, w) gnome_dialog_run_and_close(GNOME_DIALOG(gnome_error_dialog_parented(_(msg), GTK_WINDOW (w))));
 #define WARNING_DIALOG(msg, w) gnome_dialog_run_and_close(GNOME_DIALOG(gnome_warning_dialog_parented(_(msg), GTK_WINDOW (w))));
 
 
+
 /*********************** structures for the file tree ***********************/
+typedef struct
+{
+  GPtrArray *datas;
+  GNode *tree;
+
+  GPtrArray *descriptions;
+  GPtrArray *categories;
+
+  GtkWidget *ctree;
+
+  GNode *selected_folder;
+  GNode *currently_displayed_gnode;
+
+  gboolean is_modified;
+
+  GString *catalog_filename;
+  gboolean catalog_filename_is_valid;
+}
+FOLDER;
+
 typedef struct
 {
   GString *name;		/* name of the file/dir */
@@ -51,18 +76,11 @@ typedef struct
   guint16 categorie;
   guint16 description;
   GString *information;
-  GNode *node;
-  GtkCTreeNode *ctree_node;
+  GNode *node;			/* gnode associated with this FILE_DATA */
+  GtkCTreeNode *ctree_node;	/* ctree_node associated with this FILE_DATA */
 }
 FILE_DATA;
 
-typedef struct
-{
-  GPtrArray *datas;
-  GNode *tree;
-}
-FOLDER;
-
 /************ main structure to be used in nearly all functions **************/
 typedef struct
 {
@@ -91,21 +109,9 @@ typedef struct
   PIX *default_disk_pix;
   GTree *extensions;
 
-  GHashTable *stuff;
-
-  GString *catalog_filename;
-  gboolean catalog_filename_is_valid;
-  gboolean is_modified;
   gboolean getInformation;
 
-  GtkWidget *window;
   GtkWidget *search_dirtree;
-  GtkWidget *path_entry;
-  GtkWidget *ctree_window;
-  GtkWidget *clist_window;
-  GtkWidget *ctree;
-  GtkWidget *clist;
-  GtkWidget *hpaned;
   gboolean update_edit_window;
   gpointer category_widgets;
   gpointer search_widgets;
@@ -113,9 +119,6 @@ typedef struct
 
   FOLDER *racine;
 
-  GNode *selected_folder;
-  GNode *currently_displayed_gnode;
-
   pid_t current_pid;
 
   GString *mount;
@@ -123,9 +126,12 @@ typedef struct
   GString *eject_prog;
   GString *mount_point;
   GString *dummy_prog;
-
-  GPtrArray *descriptions;
-  GPtrArray *categories;
+  gboolean use_supermount;
+  
+  /* Options */
+  gboolean use_du_s;
+  gboolean warn_mount;
+  gboolean eject_disk;   
 
 /* What is that? */
   char *fast_name;
@@ -159,7 +165,8 @@ KEY_VALUE;
 
 /* Function headers */
 /* config_parser. */
-void config_struct_free_1(GList *gl);
+gboolean check_supermount(CONFIG *my_config);
+void config_struct_free_1 (GList * gl);
 int yyerror (char *s);
 void yyrestart (FILE * new_file);
 CONFIG *init_config (GString * config_file, GtkWidget * w);
@@ -167,5 +174,10 @@ CONFIG *init_config (GString * config_file, GtkWidget * w);
 /* config_lex.l */
 int yylex (void);
 
+extern GtkWidget *main_window;
+extern GtkWidget *path_entry;
+extern GtkWidget *clist;
+
+extern CONFIG *my_config;
 
 #endif
