@@ -1,6 +1,7 @@
 typedef union {
 	gint		val;
 	char		*string;
+	gboolean        gbool;  
 	GString		*gstring;
 	GArray		*garray;
 	GList		*glist;
@@ -15,10 +16,14 @@ typedef union {
 #define	EJECTPROGRAM	263
 #define	MOUNTPOINT	264
 #define	EXTENSION	265
-#define	STRING	266
-#define	QSTRING	267
-#define	INTEGER	268
-#define	EOL	269
+#define	OPTIONDUS	266
+#define	OPTIONWARNMOUNT	267
+#define	OPTIONEJECT	268
+#define	STRING	269
+#define	QSTRING	270
+#define	GBOOLEAN	271
+#define	INTEGER	272
+#define	EOL	273
 
 
 extern YYSTYPE yylval;
