@@ -24,6 +24,6 @@ GString *fread_gstring(FILE *catalog);
 FILE_DATA *fread_filedata(FILE *catalog);
 void load_folder_tree(FOLDER *folder, FILE *catalog);
 GPtrArray *load_gptrarray_of_gstrings(FILE *catalog);
-int load_cat_from_file(char *filename, CONFIG *my_config);
+int load_cat_from_file(char *filename, FOLDER *racine);
 
 #endif
