@@ -24,44 +24,17 @@
 
 typedef struct
 {
-  GtkWidget *report_dialog_window;
-  GtkWidget *disk_combo;
-  GtkWidget *cat_combobox;
-  GtkWidget *check_disks;
-  GtkWidget *check_folders;
-  GtkWidget *check_files;
-  GtkWidget *check_category;
-  GtkWidget *check_location;
-  GtkWidget *check_description;
-  GtkWidget *check_only_desc;
-  GtkWidget *check_only_cat;
-  GtkWidget *button_sortbycat;
-  GtkWidget *button_sortbyfile;
-  GSList *group_sort;
-  GtkWidget *output_entry;
-  GtkWidget *output_button;
-  GtkWidget *report_selector;
-  gboolean gb_check_disks;
-  gboolean gb_check_folders;
-  gboolean gb_check_files;
-  gboolean gb_check_category;
-  gboolean gb_check_location;
-  gboolean gb_check_description;
-  gboolean gb_check_only_desc;
-  gboolean gb_check_only_cat;
-  gint cat_to_report;
 }
 REPORT_WIDGETS;
 
 void _which_disk(GNode *gn, gpointer data);
 void _report_cats(GNode *gn, gpointer data);
-void _report_cats_disks(GNode *gn, gpointer data);
-gboolean generate_cat_report(CONFIG *my_config, FILE *file);
+gboolean generate_cat_report(FOLDER * racine, FILE * file);
 void _report_files(GNode *gn, gpointer data);
-gboolean generate_file_report(CONFIG *my_config, FILE *file);
+gboolean generate_file_report(FOLDER *racine, FILE * file);
 void begin_report(GtkWidget *w, gpointer data);
 void set_report_file(GtkWidget *w, gpointer data);
 void select_report_file(GtkWidget *w, gpointer data);
-void open_report_dialog(GtkWidget *w, gpointer data);
+void open_report_dialog (FOLDER *racine);
 
 #endif
