@@ -20,10 +20,10 @@
 
 #include "config_common.h"
 
-void fwrite_gstring(GString *g, FILE *catalog);
-void fwrite_filedata(FILE_DATA *d, FILE *catalog);
-void fwrite_subdir(GNode *gn, gpointer data);
-void fwrite_gnode(GNode *gn, gpointer data);
-int save_cat_to_file(char *filename, CONFIG *my_config);
+void fwrite_gstring (GString * g, FILE * fh);
+void fwrite_filedata (FILE_DATA * d, FILE * fh);
+void fwrite_subdir (GNode * gn);
+void fwrite_gnode (GNode * gn, gpointer data);
+int save_cat_to_file (char *filename, FOLDER * racine);
 
 #endif
